ShortArtifactsDetectSetting class final

Constructors

ShortArtifactsDetectSetting({int amplArtDetectWinSize = 200, int amplArtZerodArea = 200, int amplArtExtremumBorder = 30})

Properties

amplArtDetectWinSize int
getter/setter pair
amplArtExtremumBorder int
getter/setter pair
amplArtZerodArea int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited